# Пересборка дистрибутивов
```bash
# пересборка
rm -rf build dist *.egg-info
python -m pip install build twine
python -m build
# публикация
source .venv/Scripts/activate
python -m twine upload dist/*
```

# Проверка build.yml
```bash
yamllint .github/workflows/build.yml
```

# Запуск из консоли
```bash
python src\\aiebash\\__main__.py -s
python src\\aiebash\\__main__.py Проверь свои системы
python src\\aiebash\\__main__.py -d приведи примеры вывода списка файлов 

```

# Загрузка на PyPI
```bash                 
source .venv/Scripts/activate
python -m twine upload dist/*
```

# Удаление всех пакетов
```bash
pip freeze | xargs pip uninstall -y
```
